@@ -17,7 +17,9 @@ class Help_messages():
             ".en   技能成长\n" \
             ".set  角色卡设定\n" \
             ".show 角色卡查询\n" \
-            ".sa   快速检定"
+            ".sa   快速检定\n" \
+            ".del  删除数据\n" \
+            "输入.help+指令名获取详细信息"
         self.r = ".r[dah#bp] a_number [+/-]ex_number\n" \
             "d：骰子设定指令,标准格式为xdy，x为骰子数量y为骰子面数；\n" \
             "a：检定指令，根据后续a_number设定数值检定；\n" \
@@ -28,17 +30,24 @@ class Help_messages():
         self.sc = ".sc success/failure san_number\n" \
             "success：判定成功降低san值，支持x或xdy语法（x与y为数字）；\n" \
             "failure：判定失败降低san值，支持语法如上；\n" \
-            "san_number：当前san值，缺省an_number将会自动使用保存的人物卡数据。"
+            "san_number：当前san值，缺省san_number将会自动使用保存的人物卡数据。"
         self.set = ".set [attr_name] [attr_num]\n" \
             "attr_name：属性名称，例 name、名字、str、力量\n" \
             "attr_num：属性值\n" \
             "可以单独输入.set指令，骰娘将自动读取最近一次coc指令结果进行保存"
-        self.show = ".show [@xxx]\n" \
-            "查看指定调查员保存的人物卡，缺省at则查询自身人物卡"
+        self.show = ".show[s] [@xxx]\n" \
+            "查看指定调查员保存的人物卡，缺省at则查询自身人物卡\n" \
+            ".shows 为查看技能指令"
         self.sa = ".sa [attr_name]\n" \
             "attr_name：属性名称，例:name、名字、str、力量"
         self.en = ".en skill_level\n" \
             "skill_level：需要成长的技能当前等级。"
+        self.del_ = ".del [c|card|xxx]\n" \
+            "删除数据，args可以有以下值\n" \
+            "c:清空暂存数据\n" \
+            "card:删除使用中的人物卡(慎用)\n" \
+            "xxx:其他任意技能名\n" \
+            "该命令支持多个参数混合使用，可以一次指定多个技能名，使用空格隔开"
 
 
 help_messages = Help_messages()
